@@ -96,7 +96,7 @@ class AtlantisClient:
         :rtype: dict
         """
         response = requests.post(
-            '{}/api/instrospect-token'.format(self.atlantis_url),
+            '{}/api/introspect-token'.format(self.atlantis_url),
             data={
                 'token': access_token,
                 'token_type_hint': 'access_token',
